@@ -2,12 +2,15 @@ from enum import Enum
 
 
 class KeywordPattern:
+    """Pattern set of keyword types"""
     key = r"(?P<variable>((('|\"|`)[^:='\"`<>]*|[^:='\"`<>\s\(]*)(?P<keyword>{})[^:='\"`<>]*)('|\"|`)?)"
     separator = r"\s*\]?\s*(?P<separator>{})((\s|\w)*\((\s|\w|=|\()*|\s*)"
-    value = r"(?P<value_leftquote>(\\)*(b|r)?('|\"|`))?(?P<value>[^'\"`(\\\')(\\\")]{0,1000})(?P<value_rightquote>(\\)*('|\"|`))?"
+    value = r"(?P<value_leftquote>(\\)*(b|r)?('|\"|`))?" \
+            r"(?P<value>[^'\"`(\\\')(\\\")]{0,1000})(?P<value_rightquote>(\\)*('|\"|`))?"
 
 
 class Separator:
+    """Separators collection"""
     common = "=|:=|:"
     # All unique non-regex characters from `common`
     common_as_set = "=:"
@@ -18,6 +21,7 @@ class Separator:
 
 
 class Severity(Enum):
+    """Severity of candidate"""
     CRITICAL = "critical"
     HIGH = "high"
     MEDIUM = "medium"
@@ -25,22 +29,29 @@ class Severity(Enum):
     INFO = "info"
 
 
-class Chars:
+class Base(Enum):
+    """Stores types of character sets in lower case"""
+    base36 = "base36"
+    base64 = "base64"
+    hex = "hex"
+
+
+class Chars(Enum):
     """Stores three types characters sets.
 
     Parameters:
-        BASE64_CHARS: set of 64 characters, used in Base64 encoding
         HEX_CHARS: set of characters, hexadecimal numeral system (Base16)
         BASE36_CHARS: set of 36 characters, used in Base36 encoding
+        BASE64_CHARS: set of 64 characters, used in Base64 encoding
 
     """
-
-    BASE64_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="
     HEX_CHARS = "1234567890abcdefABCDEF"
     BASE36_CHARS = "abcdefghijklmnopqrstuvwxyz1234567890"
+    BASE64_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="
 
 
 class KeyValidationOption(Enum):
+    """API validation state"""
     INVALID_KEY = 0
     VALIDATED_KEY = 1
     UNDECIDED = 2
@@ -48,11 +59,13 @@ class KeyValidationOption(Enum):
 
 
 class GroupType(Enum):
+    """Group type"""
     KEYWORD = "keyword"
     PATTERN = "pattern"
 
 
 class RuleType(Enum):
+    """Rule type"""
     KEYWORD = "keyword"
     PATTERN = "pattern"
     PEM_KEY = "pem_key"
@@ -69,6 +82,7 @@ class ThresholdPreset(Enum):
 
 
 class DiffRowType:
+    """Diff type of row"""
     ADDED = "added"
     DELETED = "deleted"
     ADDED_ACCOMPANY = "added_accompany"
@@ -81,3 +95,8 @@ MIN_VALUE_LENGTH = 4
 MAX_LINE_LENGTH = 1500
 
 DEFAULT_ENCODING = "utf8"
+
+AVAILABLE_ENCODINGS = ("utf8", "utf16", "latin_1")
+
+# to limit memory usage in case of recursive scan
+RECURSIVE_SCAN_LIMITATION = 1 << 30
