@@ -1,5 +1,6 @@
-from typing import Dict, List
+from typing import Dict, List, Optional
 
+from humanfriendly import parse_size
 from regex import regex
 
 from credsweeper.utils import Util
@@ -21,11 +22,16 @@ class Config:
         self.exclude_extensions: List[str] = config["exclude"]["extension"]
         self.source_extensions: List[str] = config["source_ext"]
         self.source_quote_ext: List[str] = config["source_quote_ext"]
+        self.find_by_ext_list: List[str] = config["find_by_ext_list"]
         self.check_for_literals: bool = config["check_for_literals"]
         self.not_allowed_path_pattern = regex.compile(f"{Util.get_regex_combine_or(self.NOT_ALLOWED_PATH)}",
                                                       flags=regex.IGNORECASE)
-        self.ml_validation: bool = config["validation"]["ml_validation"]
         self.api_validation: bool = config["validation"]["api_validation"]
         self.use_filters: bool = config["use_filters"]
-        self.line_data_output: bool = config["line_data_output"]
-        self.candidate_output: bool = config["candidate_output"]
+        self.line_data_output: List[str] = config["line_data_output"]
+        self.candidate_output: List[str] = config["candidate_output"]
+        self.find_by_ext: bool = config["find_by_ext"]
+        self.size_limit: Optional[int] = parse_size(config["size_limit"]) if config["size_limit"] is not None else None
+        self.depth: int = int(config["depth"])
+        if self.depth > 0 and ".zip" in self.exclude_extensions:
+            self.exclude_extensions.remove(".zip")
