@@ -5,7 +5,7 @@ import yaml
 
 from credsweeper.common.constants import DEFAULT_ENCODING
 
-CONFIG_PATH = Path(__file__).resolve().parent.parent.joinpath('secret')
+CONFIG_PATH = Path(__file__).resolve().parent.parent.joinpath("secret")
 
 
 class ConfigManager:
@@ -14,7 +14,7 @@ class ConfigManager:
     def load_conf(conf_file):
         file_path = CONFIG_PATH.joinpath(conf_file)
         try:
-            with open(file_path, 'r', encoding=DEFAULT_ENCODING) as f:
+            with open(file_path, "r", encoding=DEFAULT_ENCODING) as f:
                 conf = yaml.load(f, Loader=yaml.FullLoader)
         except (IOError, OSError):
             logging.error(f"Failed to read {file_path}")
