@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from typing import List
+from typing import List, Dict
 
 from git import InvalidGitRepositoryError, NoSuchPathError, Repo
 
@@ -9,7 +9,7 @@ from credsweeper.utils import Util
 
 
 class FilePathExtractor:
-    located_repos = {}
+    located_repos: Dict[Path, Repo] = {}
 
     @classmethod
     def apply_gitignore(cls, detected_files: List[str]) -> List[str]:
@@ -47,10 +47,11 @@ class FilePathExtractor:
 
         for dirpath, _, filenames in os.walk(path):
             for filename in filenames:
-                file_path = f"{dirpath}/{filename}"
-                if FilePathExtractor.check_exclude_file(config, file_path):
+                file_path = os.path.join(f"{dirpath}", f"{filename}")
+                if FilePathExtractor.check_exclude_file(config, file_path) or FilePathExtractor.check_file_size(
+                        config, file_path):
                     continue
-                if os.path.isfile(file_path):
+                if os.path.isfile(file_path) and 0 < os.path.getsize(file_path):
                     file_paths.append(file_path)
         return file_paths
 
@@ -89,8 +90,13 @@ class FilePathExtractor:
                     return True
                 parent_directory = new_parent
 
+    @staticmethod
+    def is_find_by_ext_file(config: Config, path: str) -> bool:
+        return config.find_by_ext and Util.get_extension(path) in config.find_by_ext_list
+
     @classmethod
     def check_exclude_file(cls, config: Config, path: str) -> bool:
+        path = path.replace('\\', '/').lower()
         if config.not_allowed_path_pattern.match(path):
             return True
         if any(exclude_pattern.match(path) for exclude_pattern in config.exclude_patterns):
@@ -100,3 +106,12 @@ class FilePathExtractor:
         if Util.get_extension(path) in config.exclude_extensions:
             return True
         return False
+
+    @classmethod
+    def check_file_size(cls, config: Config, path: str) -> bool:
+        if config.size_limit is None:
+            return False
+        if os.path.getsize(path) > config.size_limit:
+            return True
+        else:
+            return False
