@@ -1,4 +1,3 @@
-from os import read
 from typing import Dict, List, Optional
 
 from credsweeper.file_handler.analysis_target import AnalysisTarget
@@ -15,7 +14,7 @@ class TextContentProvider(ContentProvider):
     """
 
     def __init__(self, file_path: str, change_type: Optional[str] = None, diff: Optional[List[Dict]] = None) -> None:
-        self.file_path = file_path
+        super().__init__(file_path)
 
     def get_analysis_target(self) -> List[AnalysisTarget]:
         """Load and preprocess file content to scan.
@@ -24,5 +23,5 @@ class TextContentProvider(ContentProvider):
             list of analysis targets based on every row in file
 
         """
-        all_lines = Util.read_file(self.file_path)
-        return [AnalysisTarget(line, i + 1, all_lines, self.file_path) for i, line in enumerate(all_lines)]
+        lines = Util.read_file(self.file_path)
+        return self.lines_to_targets(lines)
