@@ -6,7 +6,8 @@ from credsweeper.utils import Util
 
 
 class ValueAllowlistCheck(Filter):
-    """Check that patterns from the list is not present in the candidate value"""
+    """Check that patterns from the list is not present in the candidate value."""
+
     ALLOWED = [
         "ENC\\(.*\\)", "ENC\\[.*\\]", "\\$\\{.*\\}", "#\\{.*\\}", "\\{\\{.+\\}\\}", "(\\w|\\d|\\.|->)+\\(.*\\)",
         "\\*\\*\\*\\*\\*"
@@ -14,13 +15,14 @@ class ValueAllowlistCheck(Filter):
     ALLOWED_PATTERN = regex.compile(Util.get_regex_combine_or(ALLOWED), flags=regex.IGNORECASE)
 
     def run(self, line_data: LineData) -> bool:
-        """Run filter checks on received credential candidate data 'line_data'
+        """Run filter checks on received credential candidate data 'line_data'.
 
         Args:
-            line_data: LineData object, credential candidate data
+            line_data: credential candidate data
 
         Return:
-            boolean variable. True, if need to filter candidate and False if left
+            True, if need to filter candidate and False if left
+
         """
         if line_data.value is None:
             return True
