@@ -1,7 +1,8 @@
-from typing import List, Optional
+from typing import Optional
 
 from credsweeper.config import Config
 from credsweeper.credentials import Candidate
+from credsweeper.file_handler.analysis_target import AnalysisTarget
 from credsweeper.rules import Rule
 from credsweeper.scanner.scan_type import ScanType
 
@@ -17,17 +18,13 @@ class MultiPattern(ScanType):
     MAX_SEARCH_MARGIN = 10
 
     @classmethod
-    def run(cls, config: Config, line: str, line_num: int, file_path: str, rule: Rule,
-            lines: List[str]) -> Optional[Candidate]:
+    def run(cls, config: Config, rule: Rule, target: AnalysisTarget) -> Optional[Candidate]:
         """Check if multiline credential present if the file within MAX_SEARCH_MARGIN range from current line_num.
 
         Args:
             config: user configs
-            line: Line to check
-            line_num: Line number of a current line
-            file_path: Path to the file that contain current line
             rule: Rule object to check current line. Should be a multi-pattern rule
-            lines: All lines if the file
+            target: Analysis target
 
         Return:
             Candidate object if pattern defined in a rule is present in a line and second part of multi-pattern rule is
@@ -36,23 +33,20 @@ class MultiPattern(ScanType):
         """
         assert rule.pattern_type == rule.MULTI_PATTERN, \
             "Rules provided to MultiPattern.run should have pattern_type equal to MULTI_PATTERN"
-        line_data = cls.get_line_data(config, line, line_num, file_path, rule.patterns[0], rule.filters)
 
-        if line_data is None:
+        candidate = cls._get_candidate(config, rule, target)
+        if not isinstance(candidate, Candidate):
             return None
 
-        candidate = Candidate([line_data], rule.patterns, rule.rule_name, rule.severity, config, rule.validations,
-                              rule.use_ml)
         line_num_margin = 1
 
         while line_num_margin <= cls.MAX_SEARCH_MARGIN:
-            if candidate.line_data_list[0].line_num - line_num_margin >= 1 \
-                    and candidate.line_data_list[0].line_num - line_num_margin <= len(lines) \
-                    and cls.scan(config, candidate, -line_num_margin, lines, file_path, rule):
-                break
-            if candidate.line_data_list[0].line_num + line_num_margin <= len(lines) \
-                    and cls.scan(config, candidate, line_num_margin, lines, file_path, rule):
-                break
+            if 1 <= candidate.line_data_list[0].line_num - line_num_margin <= len(target.lines):
+                if cls._scan(config, candidate, -line_num_margin, target, rule):
+                    break
+            if candidate.line_data_list[0].line_num + line_num_margin <= len(target.lines):
+                if cls._scan(config, candidate, line_num_margin, target, rule):
+                    break
             line_num_margin += 1
 
         # Check if found multi line
@@ -62,8 +56,8 @@ class MultiPattern(ScanType):
         return candidate
 
     @classmethod
-    def scan(cls, config: Config, candidate: Candidate, line_num_margin: int, lines: List[str], file_path: str,
-             rule: Rule) -> bool:
+    def _scan(cls, config: Config, candidate: Candidate, line_num_margin: int, target: AnalysisTarget,
+              rule: Rule) -> bool:
         """Search for second part of multiline rule near the current line.
 
         Automatically update candidate with detected line if any.
@@ -72,8 +66,7 @@ class MultiPattern(ScanType):
             config: dict, scanner configuration
             candidate: Current credential candidate detected in the line
             line_num_margin: Number of lines around candidate to perform search
-            lines: All lines if the file
-            file_path: Path to the file that contain current line
+            target: Analysis target
             rule: Rule object to check current line. Should be a multi-pattern rule
 
         Return:
@@ -81,9 +74,10 @@ class MultiPattern(ScanType):
 
         """
         candi_line_num = candidate.line_data_list[0].line_num + line_num_margin
-        candi_line = lines[candi_line_num - 1]
+        candi_line = target.lines[candi_line_num - 1]
 
-        line_data = cls.get_line_data(config, candi_line, candi_line_num, file_path, rule.patterns[1], rule.filters)
+        line_data = cls.get_line_data(config, candi_line, candi_line_num, target.file_path, rule.patterns[1],
+                                      rule.filters)
 
         if line_data is None:
             return False
