@@ -1,3 +1,4 @@
+import logging
 from typing import List
 
 import requests
@@ -31,27 +32,30 @@ class GoogleApiKeyValidation(Validation):
             #  validate the "key", so we will know if it's real or not.
             r = requests.get(
                 f"https://maps.googleapis.com/maps/api/place/findplacefromtext/json?key={line_data_list[0].value}")
-        except requests.exceptions.ConnectionError:
+        except (requests.exceptions.ConnectionError, Exception) as exc:
+            logging.info(exc)
             return KeyValidationOption.UNDECIDED
 
         # Google sends 200 even in case of REQUEST_DENIED
         if r.status_code == 200:
-            data = r.json()
-            status = data.get("status")
+            try:
+                data = r.json()
+                status = data.get("status")
 
-            if status != "REQUEST_DENIED":
-                # VALIDATED if request is not denied
-                return KeyValidationOption.VALIDATED_KEY
-            else:
-                error_message = data.get("error_message")
-
-                # VALIDATED key is legit, but not authorized for Maps API
-                if error_message == "This API project is not authorized to use this API.":
+                if status != "REQUEST_DENIED":
+                    # VALIDATED if request is not denied
                     return KeyValidationOption.VALIDATED_KEY
-                # Invalid if Google explicitly say so
-                if error_message == "The provided API key is invalid.":
-                    return KeyValidationOption.INVALID_KEY
-                # Undecided otherwise
-                return KeyValidationOption.UNDECIDED
-        else:
-            return KeyValidationOption.UNDECIDED
+                else:
+                    error_message = data.get("error_message")
+                    # VALIDATED key is legit, but not authorized for Maps API
+                    if error_message == "This API project is not authorized to use this API.":
+                        return KeyValidationOption.VALIDATED_KEY
+                    # Invalid if Google explicitly say so
+                    if error_message == "The provided API key is invalid.":
+                        return KeyValidationOption.INVALID_KEY
+
+            except Exception as exc:
+                logging.info(exc)
+
+        # Undecided otherwise
+        return KeyValidationOption.UNDECIDED
