@@ -1,3 +1,4 @@
+import logging
 from typing import List
 
 import requests
@@ -29,19 +30,22 @@ class SlackTokenValidation(Validation):
         try:
             headers = {"Content-type": "application/json", "Authorization": f"Bearer {line_data_list[0].value}"}
             r = requests.post("https://slack.com/api/auth.test/", headers=headers)
-
-        except requests.exceptions.ConnectionError:
+        except (requests.exceptions.ConnectionError, Exception) as exc:
+            logging.info(exc)
             return KeyValidationOption.UNDECIDED
 
-        data = r.json()
+        try:
+            data = r.json()
 
-        if data.get("ok"):
-            return KeyValidationOption.VALIDATED_KEY
+            if data.get("ok"):
+                return KeyValidationOption.VALIDATED_KEY
 
-        error_message = data.get("error")
+            error_message = data.get("error")
+
+            if error_message == "invalid_auth":
+                return KeyValidationOption.INVALID_KEY
+
+        except Exception as exc:
+            logging.info(exc)
 
-        if error_message == "invalid_auth":
-            return KeyValidationOption.INVALID_KEY
-        if error_message == "not_authed":
-            return KeyValidationOption.UNDECIDED
         return KeyValidationOption.UNDECIDED
